@@ -5,8 +5,8 @@
 #' @param script script filename.
 #' @param rm whether to remove all objects from the global environment before
 #'        and after the script is run.
-#' @param clean whether to remove the target directory before running the
-#'        script.
+#' @param clean whether to \code{\link{clean}} the target directory before
+#'        running the script.
 #' @param quiet whether to suppress messages reporting progress.
 #'
 #' @details
@@ -15,10 +15,9 @@
 #' sure that only files, not objects, are carried over between scripts.
 #'
 #' Likewise, the TAF server runs with \code{clean = TRUE} to make sure that the
-#' script starts by creating a new empty directory. The target directory of a
-#' TAF script has the same filename prefix as the script: \verb{data.R} creates
-#' \file{data} etc. An important exception is that a directory called
-#' \file{begin} will never be deleted.
+#' script starts with a clean directory. The target directory of a TAF script
+#' has the same filename prefix as the script: \verb{data.R} creates \file{data}
+#' etc.
 #'
 #' @return
 #' \code{TRUE} or \code{FALSE}, indicating whether the script ran without
@@ -55,8 +54,8 @@ sourceTAF <- function(script, rm=FALSE, clean=TRUE, quiet=FALSE)
 {
   if(rm)
     rm(list=ls(.GlobalEnv), pos=.GlobalEnv)
-  if(clean && dir.exists(file_path_sans_ext(script)) && script!="begin.R")
-    unlink(file_path_sans_ext(script), recursive=TRUE)
+  if(clean && dir.exists(file_path_sans_ext(script)))
+    clean(file_path_sans_ext(script))
   if(!quiet)
     msg(script, " running...")
 
